#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_boiler_plate
----------------------------------

Tests for `boiler_plate` module.
"""

import unittest

import boiler_plate
from boiler_plate.cli import hello


class TestBoiler_plate(unittest.TestCase):

    def setUp(self):
        self.hello_message = "Hello, Fang"
        pass

    def test_something(self):
        assert(boiler_plate.__version__)
        output = hello()
        assert(output == self.hello_message)

    def tearDown(self):
        pass



from __future__ import print_function
import click

@click.command()
def cli():
    click.echo("Hello, World!")

def hello():
    return("Hello, Fang")

def say_hello():
    return(hello())

if __name__ == '__main__':
    cli()
